# Copyright 2019 Red Hat, Inc.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from oslo_config import cfg


whitebox_neutron_plugin_options = cfg.OptGroup(
    name="whitebox_neutron_plugin_options",
    title="Whitebox neutron tempest plugin config options"
)

WhiteboxNeutronPluginOptions = [
    cfg.BoolOpt('node_power_change',
                default=True,
                help='Whether to power off/on nodes, '
                'such as controller/compute.'),
    cfg.StrOpt('openstack_type',
               default='devstack',
               help='Type of openstack deployment, '
               'e.g. devstack, podified'),
    cfg.StrOpt('pki_private_key',
               default='/etc/pki/tls/private/ovn_controller.key',
               help='File with private key. Need for TLS-everywhere '
                    'environments.'),
    cfg.StrOpt('pki_certificate',
               default='/etc/pki/tls/certs/ovn_controller.crt',
               help='File with certificate for private key. Need for '
                    'TLS-everywhere environments.'),
    cfg.StrOpt('pki_ca_cert',
               default='/etc/ipa/ca.crt',
               help='File with peer CA certificate. Need for TLS-everywhere '
                    'environments.'),
    cfg.StrOpt('default_instance_interface',
               default='eth0',
               help='Default first interface name used in VM instances'
                    'Typical values are eth0, ens5, etc'),
    cfg.IntOpt('mcast_groups_count',
               default=1,
               help='How many groups to use in multicast tests. Default value '
                    'of 1 is for environments with low resources. '
                    'Recommended value is 2.'),
    cfg.IntOpt('mcast_receivers_count',
               default=1,
               help='How many receivers to use in multicast tests. Default '
                    'value of 1 is for environments with low resources. '
                    'Recommended value is 2.'),
    cfg.IntOpt('external_igmp_querier_period',
               default=170,
               help='Time in seconds external igmp querier is sending its '
                    'periodical queries'),
    cfg.BoolOpt('run_traffic_flow_tests',
                default=False,
                help='Specify explicitly whether to run traffic flow tests.'
                     ' This is needed because some ML2 plugins (e.g. ovn ) do '
                     'not expose api_extensions like dvr for some purposes.'),
    cfg.BoolOpt('provroutednetwork_support',
                default=False,
                help='Boolean that specifies if Provider Routed Networks'
                     'are supported or not'),
    cfg.IntOpt('broadcast_receivers_count',
               default=2,
               help='How many receivers to use in broadcast tests. Default '
                    'and recommended value of 2. In case of environments '
                    'with low resources, set it to 1.'),
    cfg.BoolOpt('bgp',
                default=False,
                help='Specifies whether the OSP setup under test has been '
                     'configured with BGP functionality or not'),
    cfg.IntOpt('sriov_pfs_per_host',
               default=1,
               help='Number of available PF (Physical Function) ports per'
                    'compute node on the environment under test'),
    cfg.IntOpt('sriov_vfs_per_pf',
               default=5,
               help='Number of available VF (Virtual Function) ports per'
                    'PF interface on the environment under test'),
    cfg.StrOpt('overcloud_ssh_user',
               default='zuul',
               help='Common user to access openstack nodes via ssh.'),
    cfg.StrOpt('overcloud_key_file',
               default='/home/tempest/.ssh/id_rsa',
               help='ssh private key file path for overcloud nodes access.'),
    cfg.StrOpt('neutron_config',
               default='/etc/neutron/neutron.conf',
               help='Path to neutron configuration file.'),
    cfg.StrOpt('ml2_plugin_config',
               default='/etc/neutron/plugins/ml2/ml2_conf.ini',
               help='Path to ml2 plugin config.'),
    cfg.StrOpt('ext_bridge',
               default='br-ex',
               help="OpenvSwitch bridge dedicated for external network."),
    cfg.IntOpt('ovn_max_controller_gw_ports_per_router',
               default=1,
               help='The number of network nodes used '
                    'for the OVN router HA.'),
    cfg.IntOpt('minbw_placement_nic_kbps_egress',
               default=None,
               help='BW configured per NIC for the minimum BW placement '
                    'enforcement - direction egress'),
    cfg.IntOpt('minbw_placement_nic_kbps_ingress',
               default=None,
               help='BW configured per NIC for the minimum BW placement '
                    'enforcement - direction ingress'),
    cfg.IntOpt('minbw_placement_num_nics',
               default=None,
               help='How many NICs support the minimum BW placement '
                    'enforcement'),
    cfg.IntOpt('window_size',
               default=0,
               help='Parameter for iperf command used in qos bw limit tests.'
                    'Can be used for tweaking iperf in case default value '
                    'does not work for some reason, e.g. MTU issues.'),
    cfg.StrOpt('node_tenant_interface',
               default='eth1',
               help='Physical interface of a node that intended to pass tenant'
                    'network traffic. Note: currently only environments with '
                    'the same name of the tenant interface are supported'),
    cfg.IntOpt('capture_timeout',
               default=120,
               help='Maximal time for running remote capture, in seconds. '
                    'Remote capture process will be stoppped by remote shell '
                    'when this time expires. This is needed in order to stop '
                    'remote process in case test or connection was '
                    'interrupted unexpectedly.'),
    cfg.StrOpt('proxy_host_address',
               default='',
               help='Intermediate host to run commands on podified '
                    'environment'),
    cfg.StrOpt('proxy_host_user',
               default='',
               help='User of intermediate host to run commands on podified '
                    'environment'),
    cfg.StrOpt('proxy_host_key_data',
               default='{}',
               help='Key data for accessing intermediate host on podified '
                    'environment, in dict format, i.e. {"key":"key_data"}.'
                    'The key_data should be key without first and last line '
                    'and all new lines replaced by \n'),
    cfg.StrOpt('proxy_host_inventory_path',
               default='',
               help='Nodes inventory on proxy host on podified environment'),
    cfg.IntOpt('servers_count',
               default=12,
               help='How many tenant VMs should be tested when many needed '
                    '(default value meant for cirros image).')
]
